@@ -1,5 +1,5 @@
 .onLoad <- function(lib, pkg) {
-	invisible(.C("FPUcheck",PACKAGE="PearsonDS"))
+	invisible(.C(C_FPUcheck))
 }
 
 #Removed (because of NOTE in R-2.15.0, resulting slow down should be negligible)
